SystemOrganization addCategory: #SlotsClassBuilderIntegration!

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 18:15'!
addInstVarNamed: aString
	"Add the argument, aString, as one of the receiver's instance variables."
	^Smalltalk classBuilder
		name: self name
		inEnvironment: self environment
		subclassOf: self superclass
		type: self typeOfClass
		instanceVariableNames: self instanceVariablesString, ' ', aString
		classVariableNames: self classVariablesString
		poolDictionaries: self sharedPoolsString
		category: self category
! !

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 18:15'!
removeInstVarNamed: aString 
	"Remove the argument, aString, as one of the receiver's instance variables."

	| newInstVarString |
	(self instVarNames includes: aString)
		ifFalse: [self error: aString , ' is not one of my instance variables'].
	newInstVarString := ''.
	(self instVarNames copyWithout: aString) do: 
		[:varName | newInstVarString := newInstVarString , ' ' , varName].
	^Smalltalk classBuilder
		name: self name
		inEnvironment: self environment
		subclassOf: self superclass
		type: self typeOfClass
		instanceVariableNames: newInstVarString
		classVariableNames: self classVariablesString
		poolDictionaries: self sharedPoolsString
		category: self category! !

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 18:11'!
subclass: t instanceVariableNames: f classVariableNames: d poolDictionaries: s category: cat 
	"This is the standard initialization message for creating a new class as a 
	subclass of an existing class (the receiver)."
	| class |
	class := Smalltalk classBuilder
		superclass: self
		subclass: t
		instanceVariableNames: f
		classVariableNames: d
		poolDictionaries: s
		category: cat.
	class ifNotNil:  [ class setTraitComposition: {} asTraitComposition ].
	^ class ! !

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 18:01'!
variableByteSubclass: t instanceVariableNames: f 
	classVariableNames: d poolDictionaries: s category: cat
	"This is the standard initialization message for creating a new class as a 
	subclass of an existing class (the receiver) in which the subclass is to 
	have indexable byte-sized nonpointer variables."
	^Smalltalk classBuilder
		superclass: self
		variableByteSubclass: t
		instanceVariableNames: f
		classVariableNames: d
		poolDictionaries: s
		category: cat
! !

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 18:00'!
variableSubclass: t instanceVariableNames: f 
	classVariableNames: d poolDictionaries: s category: cat
	"This is the standard initialization message for creating a new class as a 
	subclass of an existing class (the receiver) in which the subclass is to 
	have indexable pointer variables."
	^Smalltalk classBuilder
		superclass: self
		variableSubclass: t
		instanceVariableNames: f
		classVariableNames: d
		poolDictionaries: s
		category: cat
! !

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:58'!
variableWordSubclass: t instanceVariableNames: f 
	classVariableNames: d poolDictionaries: s category: cat
	"This is the standard initialization message for creating a new class as a 
	subclass of an existing class (the receiver) in which the subclass is to 
	have indexable word-sized nonpointer variables."
	^Smalltalk classBuilder
		superclass: self
		variableWordSubclass: t
		instanceVariableNames: f
		classVariableNames: d
		poolDictionaries: s
		category: cat
! !

!Class methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:55'!
weakSubclass: t instanceVariableNames: f 
	classVariableNames: d poolDictionaries: s category: cat
	"This is the standard initialization message for creating a new class as a subclass of an existing class (the receiver) in which the subclass is to have weak indexable pointer variables."
	^Smalltalk classBuilder
		superclass: self
		weakSubclass: t
		instanceVariableNames: f
		classVariableNames: d
		poolDictionaries: s
		category: cat! !

!Metaclass methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:36'!
instanceVariableNames: instVarString 
	"Declare additional named variables for my instance."
	^ Smalltalk classBuilder
		class: self
		instanceVariableNames: instVarString! !

!ClassFactoryWithOrganization methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:48'!
newClassNamed: aString subclassOf: aClass instanceVariableNames: ivNamesString classVariableNames:  classVarsString category: category
	| newClass |
	newClass := Smalltalk classBuilder
		name: aString 
		inEnvironment: self organization environment
		subclassOf: aClass
		type: aClass typeOfClass
		instanceVariableNames: ivNamesString
		classVariableNames: classVarsString
		poolDictionaries: ''
		category: category asSymbol.
	self createdClasses add: newClass.
	^newClass! !

!ClassFactoryWithOrganization methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:48'!
newSubclassOf: aClass instanceVariableNames: ivNamesString classVariableNames:  classVarsString category: category

	| newClass |
	newClass := Smalltalk classBuilder
		name: self newName 
		inEnvironment: self organization environment
		subclassOf: aClass
		type: aClass typeOfClass
		instanceVariableNames: ivNamesString
		classVariableNames: classVarsString
		poolDictionaries: ''
		category: category asSymbol.
	self createdClasses add: newClass.
	^newClass! !

!Browser methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 4/27/2013 12:20'!
copyClass
	| copysName nameOk |
	classListIndex = 0
		ifTrue: [^ self].
	self okToChange 
		ifFalse: [^ self].
	copysName := self request: 'Please type new class name' initialAnswer: self selectedClass name.
	copysName isEmptyOrNil
		ifTrue: [^ self].
	nameOk := [Smalltalk classBuilder validateClassName: copysName asSymbol] 
		on: Error 
		do: [ :ex | ^ self inform: ex printString].
	nameOk
		ifTrue: [
		"Cancel returns ''"
		self selectedClass duplicateClassWithNewName: copysName.
		self classListIndex: 0.
		self changed: #classList]! !

!Browser methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 4/27/2013 12:23'!
renameClass
	| oldName newName obs  okToRename |
	classListIndex = 0
		ifTrue: [ ^ self ].
	self okToChange 
		ifFalse: [ ^ self ].
	oldName := self selectedClass name.
	newName := self request: 'Please type new class name' initialAnswer: oldName.
	newName isEmptyOrNil
		ifTrue: [ ^ self ].	"Cancel returns ''"
	newName := newName asSymbol.
	newName = oldName
		ifTrue: [ ^ self ].
	(Smalltalk globals includesKey: newName)
		ifTrue: [ ^ self inform: newName , ' already exists' ].
	okToRename := [Smalltalk classBuilder validateClassName: newName] 
		on: Error 
		do: [ :ex | ^ self inform: ex printString].
	okToRename
		ifTrue: [
			self selectedClass rename: newName.
			self changed: #classList.
			self classListIndex: ((systemOrganizer listAtCategoryNamed: self selectedSystemCategoryName) indexOf: newName).
			obs := self systemNavigation allReferencesTo: (self selectedClass environment associationAt: newName).
			obs isEmpty
				ifFalse: [ self systemNavigation browseMessageList: obs name: 'Obsolete References to ' , oldName autoSelect: oldName ]]! !

!MCClassDefinition methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:45'!
createClass
	| superClass class composition |
	superClass := superclassName == #nil ifFalse:
						[ Smalltalk globals at: superclassName ].
	[ class := Smalltalk classBuilder
		name: name
		inEnvironment: superClass environment
		subclassOf: superClass
		type: type
		instanceVariableNames: self instanceVariablesString
		classVariableNames: self classVariablesString
		poolDictionaries: self sharedPoolsString
		category: category.] on: Warning, DuplicatedVariableError do: [:ex| ex resume].

	self traitComposition
		ifNotNil: [ composition := self class compiler evaluate: self traitComposition.
				  ((((composition isCollection and: [ ( composition includes: nil ) not])  
					or: [composition isKindOf: TraitComposition ])
						or: [composition isKindOf: Trait ])
							or: [composition isKindOf: TraitTransformation ])
					ifTrue: [ class setTraitComposition: composition asTraitComposition ] ].
	self classTraitComposition
		ifNotNil: [ composition := self class compiler evaluate: self classTraitComposition.
				  ((((composition isCollection and: [ ( composition includes: nil ) not])  
					or: [composition isKindOf: TraitComposition ])
						or: [composition isKindOf: Trait ])
							or: [composition isKindOf: TraitTransformation ])
					ifTrue: [ class class setTraitComposition: composition asTraitComposition ] ].
	^ class! !

!SmalltalkImage methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 6/14/2013 17:39'!
classBuilder
	"Answer the object responsible of creating classes."
	^ OldClassBuilderAdapter new! !

!String methodsFor: '*SlotsClassBuilderIntegration' stamp: 'MartinDias 4/27/2013 12:26'!
isLegalClassName
	"Answer whether aString is a legal  class name."

	^ [Smalltalk classBuilder validateClassName: self asSymbol] on: Error do: [^ false] ! !
